@@ -1,5 +1,5 @@
 /*
- * $Id: acl.c,v 1.71 1996/12/20 23:45:35 wessels Exp $
+ * $Id: acl.c,v 1.74 1997/01/13 23:09:44 wessels Exp $
  *
  * DEBUG: section 28    Access Control
  * AUTHOR: Duane Wessels
@@ -255,104 +255,81 @@ decode_addr(const char *asc, struct in_addr *addr, struct in_addr *mask)
     return 1;
 }
 
+static struct _acl_ip_data *
+aclParseIpData(const char *t)
+{
+    LOCAL_ARRAY(char, addr1, 256);
+    LOCAL_ARRAY(char, addr2, 256);
+    LOCAL_ARRAY(char, mask, 256);
+    struct _acl_ip_data *q = xcalloc(1, sizeof(struct _acl_ip_data));
+    if (!strcasecmp(t, "all")) {
+	q->addr1.s_addr = 0;
+	q->addr2.s_addr = 0;
+	q->mask.s_addr = 0;
+	return q;
+    }
+    memset(addr1, 0, 256);
+    memset(addr2, 0, 256);
+    memset(mask, 0, 256);
+    if (sscanf(t, "%[0-9.]-%[0-9.]/%[0-9.]", addr1, addr2, mask) == 3) {
+	(void) 0;
+    } else if (sscanf(t, "%[0-9.]-%[0-9.]", addr1, addr2) == 2) {
+	mask[0] = '\0';
+    } else if (sscanf(t, "%[0-9.]/%[0-9.]", addr1, mask) == 2) {
+	addr2[0] = '\0';
+    } else if (sscanf(t, "%[0-9.]", addr1) == 1) {
+	addr2[0] = '\0';
+	mask[0] = '\0';
+    } else if (sscanf(t, "%[^/]/%s", addr1, mask) == 2) {
+	addr2[0] = '\0';
+    } else if (sscanf(t, "%s", addr1) == 1) {
+	addr2[0] = '\0';
+	mask[0] = '\0';
+    } else {
+	debug(28, 0, "aclParseIpList: Bad host/IP: '%s'\n", t);
+	safe_free(q);
+	return NULL;
+    }
+    /* Decode addr1 */
+    if (!decode_addr(addr1, &q->addr1, &q->mask)) {
+	debug(28, 0, "%s line %d: %s\n",
+	    cfg_filename, config_lineno, config_input_line);
+	debug(28, 0, "aclParseIpList: Ignoring invalid IP acl entry: unknown first address '%s'\n", addr1);
+	safe_free(q);
+	return NULL;
+    }
+    /* Decode addr2 */
+    if (*addr2 && !decode_addr(addr2, &q->addr2, &q->mask)) {
+	debug(28, 0, "%s line %d: %s\n",
+	    cfg_filename, config_lineno, config_input_line);
+	debug(28, 0, "aclParseIpList: Ignoring invalid IP acl entry: unknown second address '%s'\n", addr2);
+	safe_free(q);
+	return NULL;
+    }
+    /* Decode mask */
+    if (*mask && !decode_addr(mask, &q->mask, NULL)) {
+	debug(28, 0, "%s line %d: %s\n",
+	    cfg_filename, config_lineno, config_input_line);
+	debug(28, 0, "aclParseIpList: Ignoring invalid IP acl entry: unknown netmask '%s'\n", mask);
+	safe_free(q);
+	return NULL;
+    }
+    q->addr1.s_addr &= q->mask.s_addr;
+    q->addr2.s_addr &= q->mask.s_addr;
+    /* 1.2.3.4/255.255.255.0  --> 1.2.3.0 */
+    return q;
+}
 
 static struct _acl_ip_data *
 aclParseIpList(void)
 {
     char *t = NULL;
-    char *p = NULL;
     struct _acl_ip_data *head = NULL;
     struct _acl_ip_data **Tail = &head;
     struct _acl_ip_data *q = NULL;
-    LOCAL_ARRAY(char, addr1, 256);
-    LOCAL_ARRAY(char, addr2, 256);
-    LOCAL_ARRAY(char, mask, 256);
-
     while ((t = strtokFile())) {
-	q = xcalloc(1, sizeof(struct _acl_ip_data));
-	if (!strcasecmp(t, "all")) {
-	    q->addr1.s_addr = 0;
-	    q->addr2.s_addr = 0;
-	    q->mask.s_addr = 0;
-	} else {
-	    p = t;
-	    memset(addr1, 0, 256);
-	    memset(addr2, 0, 256);
-	    memset(mask, 0, 256);
-
-#ifdef OLD_CODE
-	    /* This breaks on "www-cache.uninett.no" because of the dash */
-	    /* Split the adress in addr1-addr2/mask */
-	    strncpy(addr1, p, strcspn(p, "-/"));
-	    p += strcspn(p, "-/");
-	    if (*p == '-') {
-		p++;
-		strncpy(addr2, p, strcspn(p, "/"));
-		p += strcspn(p, "/");
-	    }
-	    if (*p == '/') {
-		p++;
-		strcpy(mask, p);
-	    }
-#endif
-#ifndef NEW_CODE
-	    for (;;) {
-		if (sscanf(t, "%[0-9.]-%[0-9.]/%[0-9.]", addr1, addr2, mask) == 3)
-		    break;
-		if (sscanf(t, "%[0-9.]-%[0-9.]", addr1, addr2) == 2) {
-		    mask[0] = '\0';
-		    break;
-		}
-		if (sscanf(t, "%[0-9.]/%[0-9.]", addr1, mask) == 2) {
-		    addr2[0] = '\0';
-		    break;
-		}
-		if (sscanf(t, "%[0-9.]", addr1) == 1) {
-		    addr2[0] = '\0';
-		    mask[0] = '\0';
-		    break;
-		}
-		if (sscanf(t, "%[^/]/%s", addr1, mask) == 2) {
-		    addr2[0] = '\0';
-		    break;
-		}
-		if (sscanf(t, "%s", addr1) == 1) {
-		    addr2[0] = '\0';
-		    mask[0] = '\0';
-		    break;
-		}
-		debug(28, 0, "aclParseIpList: Bad host/IP: '%s'\n", t);
-		break;
-	    }
-#endif
-	    /* Decode addr1 */
-	    if (!decode_addr(addr1, &q->addr1, &q->mask)) {
-		debug(28, 0, "%s line %d: %s\n",
-		    cfg_filename, config_lineno, config_input_line);
-		debug(28, 0, "aclParseIpList: Ignoring invalid IP acl entry: unknown first address '%s'\n", addr1);
-		safe_free(q);
-		continue;
-	    }
-	    /* Decode addr2 */
-	    if (*addr2 && !decode_addr(addr2, &q->addr2, &q->mask)) {
-		debug(28, 0, "%s line %d: %s\n",
-		    cfg_filename, config_lineno, config_input_line);
-		debug(28, 0, "aclParseIpList: Ignoring invalid IP acl entry: unknown second address '%s'\n", addr2);
-		safe_free(q);
-		continue;
-	    }
-	    /* Decode mask */
-	    if (*mask && !decode_addr(mask, &q->mask, NULL)) {
-		debug(28, 0, "%s line %d: %s\n",
-		    cfg_filename, config_lineno, config_input_line);
-		debug(28, 0, "aclParseIpList: Ignoring invalid IP acl entry: unknown netmask '%s'\n", mask);
-		safe_free(q);
-		continue;
-	    }
-	    q->addr1.s_addr &= q->mask.s_addr;
-	    q->addr2.s_addr &= q->mask.s_addr;
-	    /* 1.2.3.4/255.255.255.0  --> 1.2.3.0 */
-	}
+	if ((q = aclParseIpData(t)) == NULL)
+	    continue;
 	*(Tail) = q;
 	Tail = &q->next;
     }
