@@ -1,6 +1,6 @@
 
 /*
- * $Id: client_side.c,v 1.74 1996/12/14 18:56:03 wessels Exp $
+ * $Id: client_side.c,v 1.81 1996/12/20 23:22:24 wessels Exp $
  *
  * DEBUG: section 33    Client-side Routines
  * AUTHOR: Duane Wessels
@@ -35,6 +35,7 @@ static void clientRedirectDone _PARAMS((void *data, char *result));
 static void icpHandleIMSReply _PARAMS((int fd, StoreEntry * entry, void *data));
 static void clientLookupDstIPDone _PARAMS((int fd, const ipcache_addrs *, void *data));
 static void clientLookupSrcFQDNDone _PARAMS((int fd, const char *fqdn, void *data));
+static void clientLookupDstFQDNDone _PARAMS((int fd, const char *fqdn, void *data));
 static int clientGetsOldEntry _PARAMS((StoreEntry * new, StoreEntry * old, request_t * request));
 static int checkAccelOnly _PARAMS((icpStateData * icpState));
 
@@ -68,6 +69,18 @@ clientLookupSrcFQDNDone(int fd, const char *fqdn, void *data)
     clientAccessCheck(icpState, icpState->aclHandler);
 }
 
+static void
+clientLookupDstFQDNDone(int fd, const char *fqdn, void *data)
+{
+    icpStateData *icpState = data;
+    debug(33, 5, "clientLookupDstFQDNDone: FD %d, '%s', FQDN %s\n",
+	fd,
+	icpState->url,
+	fqdn ? fqdn : "NULL");
+    icpState->aclChecklist->state[ACL_SRC_DOMAIN] = ACL_LOOKUP_DONE;
+    clientAccessCheck(icpState, icpState->aclHandler);
+}
+
 static void
 clientLookupIdentDone(void *data)
 {
@@ -125,6 +138,7 @@ clientAccessCheck(icpStateData * icpState, void (*handler) (icpStateData *, int)
     int answer = 1;
     aclCheck_t *ch = NULL;
     char *browser = NULL;
+    const ipcache_addrs *ia = NULL;
 
     if (Config.identLookup && icpState->ident.state == IDENT_NONE) {
 	icpState->aclHandler = handler;
@@ -141,6 +155,9 @@ clientAccessCheck(icpStateData * icpState, void (*handler) (icpStateData *, int)
 	} else {
 	    icpState->aclChecklist->browser[0] = '\0';
 	}
+	xstrncpy(icpState->aclChecklist->ident,
+	    icpState->ident.ident,
+	    ICP_IDENT_SZ);
     }
 #if USE_PROXY_AUTH
     if (clientProxyAuthCheck(icpState) == 0) {
@@ -179,6 +196,15 @@ clientAccessCheck(icpStateData * icpState, void (*handler) (icpStateData *, int)
 		clientLookupSrcFQDNDone,
 		icpState);
 	    return;
+	} else if (ch->state[ACL_DST_DOMAIN] == ACL_LOOKUP_NEED) {
+	    ch->state[ACL_DST_DOMAIN] = ACL_LOOKUP_PENDING;	/* first */
+	    ia = ipcacheCheckNumeric(icpState->request->host);
+	    if (ia != NULL)
+		fqdncache_nbgethostbyaddr(ia->in_addrs[0],
+		    icpState->fd,
+		    clientLookupDstFQDNDone,
+		    icpState);
+	    return;
 	}
     }
     requestUnlink(icpState->aclChecklist->request);
@@ -559,3 +585,32 @@ modifiedSince(StoreEntry * entry, request_t * request)
 	return 1;
     }
 }
+
+char *
+clientConstructTraceEcho(icpStateData * icpState)
+{
+    LOCAL_ARRAY(char, line, 256);
+    LOCAL_ARRAY(char, buf, 8192);
+    size_t len;
+    memset(buf, '\0', 8192);
+    sprintf(buf, "HTTP/1.0 200 OK\r\n");
+    sprintf(line, "Date: %s\r\n", mkrfc1123(squid_curtime));
+    strcat(buf, line);
+    sprintf(line, "Server: Squid/%s\r\n", SQUID_VERSION);
+    strcat(buf, line);
+    sprintf(line, "Content-Type: message/http\r\n");
+    strcat(buf, line);
+    strcat(buf, "\r\n");
+    len = strlen(buf);
+    httpBuildRequestHeader(icpState->request,
+	icpState->request,
+	NULL,			/* entry */
+	icpState->request_hdr,
+	NULL,			/* in_len */
+	buf + len,
+	8192 - len,
+	icpState->fd);
+    icpState->log_type = LOG_TCP_MISS;
+    icpState->http_code = 200;
+    return buf;
+}
