@@ -1,6 +1,6 @@
 
 /*
- * $Id: squid.h,v 1.89 1997/01/03 22:59:17 wessels Exp $
+ * $Id: squid.h,v 1.91 1997/01/07 20:31:23 wessels Exp $
  *
  * AUTHOR: Duane Wessels
  *
@@ -245,23 +245,10 @@ typedef unsigned long u_num32;
 
 #include "ansiproto.h"
 
-#if HAVE_REGEX_H && !defined(_SQUID_NEXT_)
-#include <regex.h>
-#else /* HAVE_REGEX_H */
+#ifdef USE_GNUREGEX
 #include "GNUregex.h"
-#endif /* HAVE_REGEX_H */
-
-/*
- * So if FD_SETSIZE is less than SQUID_MAXFD we'd probably better
- * shrink SQUID_MAXFD so that select(2) doesn't puke even though
- * we might really be able to open more than FD_SETSIZE descriptors.
- * happy happy happy joy joy joy.
- */
-#if defined(FD_SETSIZE) && defined(SQUID_MAXFD)
-#if FD_SETSIZE < SQUID_MAXFD
-#undef SQUID_MAXFD
-#define SQUID_MAXFD FD_SETSIZE
-#endif
+#elif HAVE_REGEX_H
+#include <regex.h>
 #endif
 
 typedef void (*SIH) (int, void *);	/* swap in */
@@ -329,6 +316,7 @@ extern int opt_syslog_enable;	/* main.c */
 extern int opt_catch_signals;	/* main.c */
 extern int opt_no_ipcache;	/* main.c */
 extern int vhost_mode;		/* main.c */
+extern int Squid_MaxFD;		/* main.c */
 extern const char *const version_string;	/* main.c */
 extern const char *const appname;	/* main.c */
 extern struct in_addr local_addr;	/* main.c */
